@@ -1,11 +1,5 @@
-# -*- coding: utf-8 -*-
-
-# Standard library imports
-
-# Third party imports
 from django.core.exceptions import ImproperlyConfigured
 
-# Local application / specific library imports
 from .bbcode.tag import BBCodeTag
 from .conf import settings as bbcode_settings
 from .core.loading import load
@@ -55,10 +49,11 @@ class TagPool(object):
         tag_name = tag.name
         if tag_name in self.tags:
             raise TagAlreadyRegistered(
-                'Cannot register {!r}, a tag with this name ({!r}) is already registered'.format(tag, tag_name)
+                'Cannot register {!r}, a tag with this name ({!r}) '
+                'is already registered'.format(tag, tag_name)
             )
 
-        # The tag cannot be registered if it is already stored as bbcode tag in the database
+        # The tag cannot be registered if it is already stored as bbcode tag in the database
         bbcode_tag_qs = DbBBCodeTag.objects.filter(tag_name=tag_name)
         if bbcode_tag_qs.exists() and bbcode_settings.BBCODE_ALLOW_CUSTOM_TAGS:
             raise TagAlreadyCreated(
